<?php

namespace EventPortal\Concerns;

use Illuminate\Database\Eloquent\Builder;
use Spatie\Enum\Enum;

trait CanBeArchived
{
    public function archive(?Enum $status = null): void
    {
        $this->archived_at = now();

        if ($status !== null) {
            $this->setStatus($status);
        }

        $this->save();
    }

    public function unArchive(): void
    {
        $this->archived_at = null;

        $this->save();
    }

    public function isArchived(): bool
    {
        return $this->archived_at !== null;
    }

    public function isNotArchived(): bool
    {
        return $this->archived_at === null;
    }

    public function scopeIsArchived(Builder $query): Builder
    {
        return $query->whereNotNull('archived_at');
    }

    public function scopeIsNotArchived(Builder $query): Builder
    {
        return $query->whereNull('archived_at');
    }
}
