<?php

namespace EventPortal\Domain\Event\Models;

use EventPortal\Concerns\AddToCasts;
use EventPortal\Concerns\AddToFillable;
use EventPortal\Concerns\CanBeArchived;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Delegate\Models\Delegate;
use EventPortal\Domain\Event\Enums\EventStatus;
use EventPortal\Domain\Model;
use EventPortal\Domain\Table\Concerns\HasTable;
use Illuminate\Database\Eloquent\Relations\BelongsToMany;

class Event extends Model
{
    use HasTable,
        AddToFillable,
        AddToCasts,
        CanBeArchived;

    public const KEY = 'event';

    /** @var string<string> */
    protected $dates = [
        'archived_at',
    ];

    /** @var array<string> */
    protected $fillable = [
        'name',
        'url',
        'status',
        'archived_at',
    ];

    /** @var array<string> */
    protected $casts = [
        'status' => 'array',
    ];

    public function delegates(): BelongsToMany
    {
        return $this->belongsToMany(Delegate::class);
    }

    public function setStatus(EventStatus $status): void
    {
        $this->status = Option::make($status->getName())->value($status->getValue());

        $this->save();
    }
}
