<?php

namespace EventPortal\Providers;

use EventPortal\Exceptions\Handler;
use Illuminate\Contracts\Debug\ExceptionHandler;
use Illuminate\Support\ServiceProvider;
use Inertia\Inertia;

class AppServiceProvider extends ServiceProvider
{
    /** @var string */
    protected $root = __DIR__.'/../..';

    public function boot(): void
    {
        $this->app->booted(function (): void {
            $this->loadRoutesFrom("{$this->root}/routes/routes.php");
        });

        $this->loadViewsFrom("{$this->root}/resources/views", 'EventPortal');

        $this->loadMigrationsFrom("{$this->root}/database/migrations");

        $this->loadFactoriesFrom("{$this->root}/database/factories");

        $this->app->bind(ExceptionHandler::class, Handler::class);

        $this->publishes([
            "{$this->root}/tables/delegate.php" => '/tables/delegates.php',
            "{$this->root}/tables/event.php" => '/tables/event.php',
            "{$this->root}/tables/event-delegate.php" => '/tables/event-delegate.php',
        ], 'tables');

        $this->publishes([
            "{$this->root}/forms/delegate.php" => '/forms/delegates.php',
            "{$this->root}/forms/event.php" => '/forms/event.php',
            "{$this->root}/forms/event-delegate.php" => '/forms/event-delegate.php',
        ], 'forms');

        Inertia::setRootView('EventPortal::app');

        Inertia::share([
            'errors' => function () {
                return session('errors') ? session('errors')->getBag('default')->getMessages() : (object) [];
            },
        ]);
    }

    public function register(): void
    {
    }
}
