<?php

namespace EventPortal\Tests\Unit\Component;

use EventPortal\Domain\Component\Actions;
use EventPortal\Domain\Component\Button;
use EventPortal\Tests\TestCase;
use Spatie\Snapshots\MatchesSnapshots;

class ActionsTest extends TestCase
{
    use MatchesSnapshots;

    /** @test **/
    public function can_make_actions()
    {
        $actions = Actions::make();

        $this->assertInstanceOf(Actions::class, $actions);
    }

    /** @test **/
    public function can_add_array_of_actions()
    {
        $buttons = [
            Button::make('Delete'),
            Button::make('Edit'),
        ];

        $actions = Actions::make()->add($buttons)->get();

        $this->assertMatchesJsonSnapshot($actions);
    }

    /** @test **/
    public function actions_are_added_when_clause_is_true()
    {
        $buttons = [
            Button::make('Delete'),
            Button::make('Edit'),
        ];

        $actions = Actions::make()->when(true, $buttons)->get();

        $this->assertMatchesJsonSnapshot($actions);
    }

    /** @test **/
    public function actions_are_not_added_when_clause_is_false()
    {
        $buttons = [
            Button::make('Delete'),
            Button::make('Edit'),
        ];

        $actions = Actions::make()->when(false, $buttons)->get();

        $this->assertMatchesJsonSnapshot($actions);
    }
}
