<?php

namespace EventPortal\Tests\Unit\Event\Actions;

use Carbon\Carbon;
use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Actions\ArchiveEvent;
use EventPortal\Domain\Event\Actions\UnArchiveEvent;
use EventPortal\Domain\Event\Enums\EventStatus;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class ArchiveEventTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_archive_event(): void
    {
        Carbon::setTestNow('2020-06-19 16:40:00');

        $event = factory(Event::class)->create();

        (new ArchiveEvent)->execute($event);

        $this->assertEquals('2020-06-19 16:40:00', $event->archived_at);
    }

    /** @test */
    public function can_un_archive_event(): void
    {
        $event = factory(Event::class)->create();

        (new UnArchiveEvent)->execute($event);

        $this->assertNull($event->archived_at);
    }

    /** @test **/
    public function sets_status_to_unpublished()
    {
        $event = factory(Event::class)->create(['status' => EventStatus::registration_open()]);

        (new ArchiveEvent)->execute($event);

        $this->assertEquals(Option::make('Unpublished')->toArray(), $event->status);
    }
}
