<?php

namespace EventPortal\Tests\Unit\Event\Models;

use EventPortal\Domain\Component\Option;
use EventPortal\Domain\Event\Enums\EventStatus;
use EventPortal\Domain\Event\Models\Event;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class EventModelTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_be_archived()
    {
        $event = factory(Event::class)->create();

        $this->assertNull($event->archived_at);

        $event->archive();

        $this->assertNotNull($event->archived_at);
    }

    /** @test **/
    public function can_be_archived_with_status()
    {
        $event = factory(Event::class)->create(['status' => EventStatus::registration_open()]);

        $this->assertNull($event->archived_at);

        $event->archive(EventStatus::unpublished());

        $this->assertNotNull($event->archived_at);
        $this->assertEquals(Option::make('Unpublished')->toArray(), $event->status);
    }

    /** @test **/
    public function can_be_unarchived()
    {
        $event = factory(Event::class)->state('archived')->create();

        $event->unArchive();

        $this->assertNull($event->archived_at);
    }

    /** @test **/
    public function can_determine_if_archived()
    {
        $event = factory(Event::class)->state('archived')->create();

        $this->assertTrue($event->isArchived());
    }

    /** @test **/
    public function can_determine_if_not_archived()
    {
        $event = factory(Event::class)->create();

        $this->assertTrue($event->isNotArchived());
    }

    /** @test **/
    public function can_scope_to_archived_models()
    {
        $eventA = factory(Event::class)->create();
        $eventB = factory(Event::class)->state('archived')->create();

        $results = Event::query()->isArchived()->get();

        $this
            ->assertNotContainsModel($eventA, $results)
            ->assertContainsModel($eventB, $results);
    }

    /** @test **/
    public function can_scope_to_none_archived_models()
    {
        $eventA = factory(Event::class)->create();
        $eventB = factory(Event::class)->state('archived')->create();

        $results = Event::query()->isNotArchived()->get();

        $this
            ->assertContainsModel($eventA, $results)
            ->assertNotContainsModel($eventB, $results);
    }
}
